@@ -30,6 +30,12 @@ class DockerConfig(BaseModel):
     max_wait_time: int = Field(
         default=30, description="Maximum wait time for container startup (seconds)"
     )
+    slow_query_threshold_ms: int = Field(
+        default=1000, description="Slow query threshold in milliseconds"
+    )
+    enable_auto_explain: bool = Field(
+        default=True, description="Enable auto_explain extension"
+    )
 
 
 class DockerManager:
@@ -114,7 +120,14 @@ class DockerManager:
                     logger.info(f"Pulling image: {self.config.image}")
                     client.images.pull(self.config.image)
 
-                # Create container with pg_hba.conf configuration for external access
+                # Get the path to our custom postgresql.conf
+                current_dir = os.path.dirname(os.path.abspath(__file__))
+                custom_conf_path = os.path.join(
+                    current_dir, "assets", "postgresql.conf"
+                )
+
+                # Use standard PostgreSQL startup without custom config file override
+                # The custom config will be applied after initialization
                 self.container = client.containers.run(
                     image=self.config.image,
                     name=self.config.container_name,
@@ -128,29 +141,30 @@ class DockerManager:
                         self.config.data_volume: {
                             "bind": "/var/lib/postgresql/data",
                             "mode": "rw",
-                        }
+                        },
+                        custom_conf_path: {
+                            "bind": "/etc/mcp_postgresql.conf",
+                            "mode": "ro",
+                        },
                     },
                     detach=True,
                     auto_remove=False,
                     restart_policy={"Name": "unless-stopped"},
-                    command=[
-                        "postgres",
-                        "-c",
-                        "listen_addresses=*",
-                        "-c",
-                        "log_statement=all",
-                        "-c",
-                        "log_connections=on",
-                        "-c",
-                        "log_disconnections=on",
-                    ],
                 )
 
             # Wait for PostgreSQL to be ready
             if self._wait_for_postgres_ready():
-                logger.info(
-                    f"PostgreSQL container started successfully on port {self.config.port}"
-                )
+                # Apply custom configuration after PostgreSQL is ready
+                if self._apply_custom_config():
+                    logger.info(
+                        f"PostgreSQL container started successfully on port "
+                        f"{self.config.port} with custom configuration"
+                    )
+                else:
+                    logger.warning(
+                        "PostgreSQL container started but custom configuration could not be applied"
+                    )
+
                 container_id = self.container.id if self.container else "unknown"
                 return {
                     "success": True,
@@ -262,6 +276,45 @@ class DockerManager:
         except Exception as e:
             return {"success": False, "error": str(e)}
 
+    def _apply_custom_config(self) -> bool:
+        """Apply custom PostgreSQL configuration after container startup"""
+        try:
+            if not self.container:
+                logger.warning("No container available to apply configuration")
+                return False
+
+            # Execute commands inside the container to apply custom configuration
+            # 1. Backup the original postgresql.conf
+            # 2. Copy our custom configuration
+            # 3. Reload PostgreSQL configuration
+
+            commands = [
+                # Backup original configuration
+                "cp /var/lib/postgresql/data/postgresql.conf /var/lib/postgresql/data/postgresql.conf.backup",
+                # Copy custom configuration
+                "cp /etc/mcp_postgresql.conf /var/lib/postgresql/data/postgresql.conf",
+                # Ensure proper permissions
+                "chown postgres:postgres /var/lib/postgresql/data/postgresql.conf",
+                "chmod 600 /var/lib/postgresql/data/postgresql.conf",
+                # Reload PostgreSQL configuration
+                "pg_ctl reload -D /var/lib/postgresql/data",
+            ]
+
+            for command in commands:
+                result = self.container.exec_run(command, user="postgres")
+                if result.exit_code != 0:
+                    logger.warning(
+                        f"Command failed: {command}, exit code: {result.exit_code}"
+                    )
+                    # Continue with next command even if one fails
+
+            logger.info("Custom PostgreSQL configuration applied successfully")
+            return True
+
+        except Exception as e:
+            logger.error(f"Failed to apply custom configuration: {e}")
+            return False
+
 
 def load_docker_config() -> DockerConfig:
     """
@@ -279,6 +332,10 @@ def load_docker_config() -> DockerConfig:
     database = os.environ.get("MCP_DOCKER_DATABASE", "postgres")
     username = os.environ.get("MCP_DOCKER_USERNAME", "postgres")
     max_wait_time = int(os.environ.get("MCP_DOCKER_MAX_WAIT_TIME", "30"))
+    slow_query_threshold_ms = int(os.environ.get("MCP_SLOW_QUERY_THRESHOLD_MS", "1000"))
+    enable_auto_explain = (
+        os.environ.get("MCP_ENABLE_AUTO_EXPLAIN", "true").lower() == "true"
+    )
 
     return DockerConfig(
         enabled=enabled,
@@ -290,4 +347,6 @@ def load_docker_config() -> DockerConfig:
         database=database,
         username=username,
         max_wait_time=max_wait_time,
+        slow_query_threshold_ms=slow_query_threshold_ms,
+        enable_auto_explain=enable_auto_explain,
     )
